@@ -288,9 +288,9 @@ class DNSTest(unittest.TestCase):
         self.wait()
         self.assertNoError(self.errorno)
         # If the chunks are aggregated, only one TXT record should be visible. Three would show if they are not properly merged.
-        # jobscoutdaily.com.    21600   IN  TXT "v=spf1 " "include:emailcampaigns.net include:spf.dynect.net  include:ccsend.com include:_spf.elasticemail.com ip4:67.200.116.86 ip4:67.200.116.90 ip4:67.200.116.97 ip4:67.200.116.111 ip4:74.199.198.2 " " ~all"
+        # jobscoutdaily.com.    21600   IN  TXT "v=spf1 A MX " "include:emailcampaigns.net include:spf.dynect.net include:ccsend.com include:_spf.elasticemail.com ip4:67.200.116.0/24 ip4:74.199.198.0/24 " " ~all"
         self.assertEqual(len(self.result), 1)
-        self.assertEqual(self.result[0].text, 'v=spf1 include:emailcampaigns.net include:spf.dynect.net  include:ccsend.com include:_spf.elasticemail.com ip4:67.200.116.86 ip4:67.200.116.90 ip4:67.200.116.97 ip4:67.200.116.111 ip4:74.199.198.2  ~all')
+        self.assertEqual(self.result[0].text, 'v=spf1 A MX include:emailcampaigns.net include:spf.dynect.net include:ccsend.com include:_spf.elasticemail.com ip4:67.200.116.0/24 ip4:74.199.198.0/24  ~all')
 
     def test_query_txt_multiple_chunked(self):
         self.result, self.errorno = None, None
@@ -409,7 +409,7 @@ class DNSTest(unittest.TestCase):
         self.result, self.errorno = None, None
         def cb(result, errorno):
             self.result, self.errorno = result, errorno
-        ip = '8.8.8.8'
+        ip = '172.253.122.26'
         self.channel.query(ipaddress.ip_address(ip).reverse_pointer, pycares.QUERY_TYPE_PTR, cb)
         self.wait()
         self.assertNoError(self.errorno)
@@ -569,7 +569,10 @@ class DNSTest(unittest.TestCase):
         # try encoding it as utf-8
         self.channel.query(host.encode(), pycares.QUERY_TYPE_A, cb)
         self.wait()
-        self.assertEqual(self.errorno, pycares.errno.ARES_ENOTFOUND)
+        # ARES_EBADNAME correct for c-ares 1.24 and ARES_ENOTFOUND for 1.18
+        if self.errorno == pycares.errno.ARES_ENOTFOUND:
+            self.errorno = pycares.errno.ARES_EBADNAME
+        self.assertEqual(self.errorno, pycares.errno.ARES_EBADNAME)
         self.assertEqual(self.result, None)
         # use it as is (it's IDNA encoded internally)
         self.channel.query(host, pycares.QUERY_TYPE_A, cb)
